#! @TCLSH@
#
# jufprof.tcl -- profiles Tcl script
#
# Copyright (C) 1998 Stefan Hornburg
#
# Author: Stefan Hornburg <racke@gundel.han.de>
# Maintainer: Stefan Hornburg <racke@gundel.han.de>
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

set auto_path [concat @jultafdir@ $auto_path]
package require Sequence
package require Prof 0.0.9

proc cmp_calls {cmd1 cmd2} {
	global handle
	
	set calls1 [Juf::Prof::calls $handle $cmd1]
	set calls2 [Juf::Prof::calls $handle $cmd2]

	if {$calls1 < $calls2} {
		return 1
	} elseif {$calls1 > $calls2} {
		return 0
	} else {
		return -1
	}
}

proc cmp_time {cmd1 cmd2} {
	global handle
	
	set calls1 [Juf::Prof::elapsed $handle $cmd1]
	set calls2 [Juf::Prof::elapsed $handle $cmd2]

	if {$calls1 < $calls2} {
		return 1
	} elseif {$calls1 > $calls2} {
		return 0
	} else {
		return -1
	}
}

#
# drop-in replacement for builtin exit
#
proc Juf::Prof::exit {{state 0}} {
	global handle
	
	Juf::Prof::stop $handle
	foreach command [lsort -command cmp_time [Juf::Prof::commands $handle]] {
		puts "$command [Juf::Prof::calls $handle $command] [Juf::Prof::elapsed $handle $command]"
	}
	Juf::Prof::delete $handle
	Juf::Prof::_exit $state
}

rename exit Juf::Prof::_exit
rename Juf::Prof::exit exit

set script [Juf::Sequence::shift argv]

set handle [Juf::Prof::new]
Juf::Prof::start $handle
if [catch "source {$script}"] {
	puts $errorInfo
}

exit 0

# Local Variables:
# mode: tcl
# tcl-default-application: "itclsh"
# End:

