#! @TCLSH@
#
# rpminstall.tcl -- install RPM package(s)
#
# Copyright (C) 1998, 1999 Stefan Hornburg
#
# Author: Stefan Hornburg <racke@gundel.han.de>
# Maintainer: Stefan Hornburg <racke@gundel.han.de>
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

set auto_path [concat @jultafdir@ $auto_path]
package require Error 0.0.6
package require RPM 0.0.9

if [llength $argv] {
	foreach pkg $argv {
		# check if package to be installed is a file
		if ![file exists $pkg] {
			Juf::Error::error $pkg "No such file or directory"
			continue
		}
		# determine package name
		if [catch "Juf::RPM::query {$pkg} name" name] {
			Juf::Error::error $pkg $name
			continue
		}
		# record files for package if it is already installed
		if [catch "Juf::RPM::exists {$name}" result] {
			Juf::Error::error $name result
			continue
		}		
		if $result {
			if [catch "Juf::RPM::query {$name} files" result] {
				Juf::Error::error $name $result
				continue
			}
			foreach file $result {
				set oldfiles($file) ""
			}
		}
		# add files for any package that is obsoleted by the current one
		if [catch "Juf::RPM::query {$pkg} obsoletes" pkglist] {
			Juf::Error::error $pkg $pkglist
			continue
		}
		foreach otherpkg $pkglist {
			if [catch "Juf::RPM::query {$otherpkg} files" result] {
				Juf::Error::error $otherpkg $result
				continue
			}
			foreach file $result {
				set oldfiles($file) ""
			}
		}
		# check for conflicts with files on the file system
		if [catch "Juf::RPM::query {$pkg} files" result] {
			Juf::Error::error $pkg $result
			continue
		} else {
			foreach file $result {
				# complain if file exists and not belongs
				# to already installed package of the same name
				if {[file exists $file] && ![file isdirectory $file]} {
					if ![info exists oldfiles($file)] {
						Juf::Error::error $pkg $file "File already exists"
					}
				}
			}
		}
		# install package
		if [catch "Juf::RPM::install {$pkg}" result] {
			Juf::Error::error $pkg $result
			continue
		}
	}
} else {
	Juf::Error::error "no RPM packages given"
}
Juf::Error::finish

