# This is a -*- Tcl -*- library script and belongs to the
# `Jumble Library for Tcl and Friends'.
#
# shell.tcl --- Handling subprocesses
#
# Copyright (C) 1996, 1998 Stefan Hornburg
#
# Author: Stefan Hornburg <racke@gundel.han.de>
# Maintainer: Stefan Hornburg <racke@gundel.han.de>
# Version: see end of file
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
# 
# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

package require Error
package require Flow 0.0.6

namespace eval Juf {
	namespace eval Shell {
		# command called if `run' encounters error
		variable errhandler Juf::Error::fatal
		# command output from last `run' invocation
		variable output ""
	}
}

# --------------------------------------------------------
# COMMAND: run COMMAND [ARG ...]
#
# Passes ARG arguments to COMMAND and returns exit status.
# Calls `errhandler' if COMMAND cannot be executed.
# --------------------------------------------------------

proc Juf::Shell::run {command args} {
	global errorCode

	variable errhandler
	variable output ""
	
	set retval 0
	if [catch "exec {$command} $args" output] {
		Juf::Flow::branch [lindex $errorCode 0] POSIX {
			eval $errhandler {$command} {[lindex $errorCode 2]}
		} CHILDSTATUS {
			# return works not as expected within Juf::Flow::branch
			set retval [lindex $errorCode 2]
		} default {
			set output ""
			eval $errhandler {$command} {unknown error (errorCode = $errorCode)}
		}
	}

	return $retval
}

# serves as file version as well
package provide Shell 0.0.9
